Uses of Class org.openqa.selenium.server.BrowserSessionFactory.BrowserSessionInfo (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.BrowserSessionFactory.BrowserSessionInfo

Packages that use BrowserSessionFactory.BrowserSessionInfo
org.openqa.selenium.server | Provides the core Selenium Server classes.

Uses of BrowserSessionFactory.BrowserSessionInfo in org.openqa.selenium.server

Fields in org.openqa.selenium.server with type parameters of type BrowserSessionFactory.BrowserSessionInfo
`protected java.util.Set<BrowserSessionFactory.BrowserSessionInfo>` | `BrowserSessionFactory.activeSessions`
`protected java.util.Set<BrowserSessionFactory.BrowserSessionInfo>` | `BrowserSessionFactory.availableSessions`

Methods in org.openqa.selenium.server that return BrowserSessionFactory.BrowserSessionInfo
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.createNewRemoteSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfiguration, boolean ensureClean, RemoteControlConfiguration configuration)` Creates and tries to open a new session.
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.getNewBrowserSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfigurations, boolean useCached, boolean ensureClean, RemoteControlConfiguration configuration)` Gets a new browser session
`BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.getNewBrowserSession(java.lang.String browserString, java.lang.String startURL, java.lang.String extensionJs, BrowserConfigurationOptions browserConfigurations, RemoteControlConfiguration configuration)` Gets a new browser session, using the SeleniumServer static fields to populate parameters.
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.grabAvailableSession(java.lang.String browserString, java.lang.String baseUrl)` Retrieves an available, unused session from the cache.
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.lookupInfoByBrowserAndUrl(java.lang.String browserString, java.lang.String baseUrl, java.util.Set<BrowserSessionFactory.BrowserSessionInfo> set)` Looks up a session in the named set by browser string and base URL
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.lookupInfoBySessionId(java.lang.String sessionId, java.util.Set<BrowserSessionFactory.BrowserSessionInfo> set)` Looks up a session in the named set by session id

Methods in org.openqa.selenium.server with parameters of type BrowserSessionFactory.BrowserSessionInfo
`protected void` | `BrowserSessionFactory.addToAvailableSessions(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` for testing only
`void` | `SeleniumServer.deregisterBrowserSession(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` De-registers a previously registered running browser session
`void` | `SeleniumDriverResourceHandler.deregisterBrowserSession(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` De-registers the given browser session from among the active sessions.
`protected void` | `BrowserSessionFactory.deregisterExternalSession(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` Removes a previously registered external browser session from the list of active sessions.
`protected static boolean` | `BrowserSessionFactory.BrowserSessionInfo.isValid(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` Browser sessions require the session id, the browser, the base URL, and the launcher.
`void` | `SeleniumServer.registerBrowserSession(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` Registers a running browser session
`void` | `SeleniumDriverResourceHandler.registerBrowserSession(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` Registers the given browser session among the active sessions to handle.
`protected boolean` | `BrowserSessionFactory.registerExternalSession(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` Adds a browser session that was not created by this factory to the set of active sessions.
`protected void` | `BrowserSessionFactory.shutdownBrowserAndClearSessionData(BrowserSessionFactory.BrowserSessionInfo sessionInfo)` Shuts down this browser session's launcher and clears out its session data (if session is not null).

Method parameters in org.openqa.selenium.server with type arguments of type BrowserSessionFactory.BrowserSessionInfo
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.lookupInfoByBrowserAndUrl(java.lang.String browserString, java.lang.String baseUrl, java.util.Set<BrowserSessionFactory.BrowserSessionInfo> set)` Looks up a session in the named set by browser string and base URL
`protected BrowserSessionFactory.BrowserSessionInfo` | `BrowserSessionFactory.lookupInfoBySessionId(java.lang.String sessionId, java.util.Set<BrowserSessionFactory.BrowserSessionInfo> set)` Looks up a session in the named set by session id

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.